<?php

global $index_text;
$index_text = array (

'search'        =>  'Suchen',
'alltasktypes'  =>  'Alle Aufgabentypen',
'allseverities' =>  'Alle Schweregrade',
'alldevelopers' =>  'Alle Entwickler',
'notyetassigned'=>  'Noch nicht zugeteilt',
'allcategories' =>  'Alle Kategorien',
'allstatuses'   =>  'Alle Status',
'allopentasks'  =>  'Alle offenen Aufgaben',
'sortthiscolumn'=>  'Nach dieser Spalte sortieren',
'id'            =>  'ID',
'tasktype'      =>  'Aufgabentyp',
'severity'      =>  'Schweregrad',
'summary'       =>  'Zusammenfassung',
'dateopened'    =>  'Datum',
'status'        =>  'Status',
'progress'      =>  'Fortschritt',
'complete'      =>  'erledigt',
'previous'      =>  'Vorige',
'next'          =>  'Nächste',

// Added in version 0.9.5
'searchthisproject' =>  'Dieses Projekt durchsuchen',

// Added in version 0.9.6
'closed'        =>  'Geschlossen',
'dueanyversion' =>  'Fällig in beliebiger Version',
'dueversion'    =>  'Fällig in',
'project'       =>  'Projekt',
'category'      =>  'Kategorie',
'lastedit'      =>  'Zuletzt geändert',
'assignedto'    =>  'Zugeteilt',
'os'            =>  'Betriebssystem',
'reportedin'    =>  'Berichtete Version',
'openedby'      =>  'Geöffnet von',
'comments'      =>  'Kommentare',
'attachments'   =>  'Anhänge',
'priority'      =>  'Priorität',

);
?>
